@@ -43,7 +43,7 @@ Foundation; version 2 of the licence.
 #include "wrappers.h"
 #include "threads.h"
 
-GList * disc_matches = NULL;
+GList * gbl_disc_matches = NULL;
 gboolean track_format[100];
 
 GtkWidget * win_main = NULL;
@@ -91,14 +91,12 @@ int main(int argc, char *argv[])
     gdk_threads_init();
     gtk_init(&argc, &argv);
     
-    add_pixmap_directory(PACKAGE_DATA_DIR "/pixmaps");
-#ifdef DEBUG
-    printf("Pixmap dir: " PACKAGE_DATA_DIR "/pixmaps\n");
-#endif
-    
     global_prefs = get_default_prefs();
     load_prefs(global_prefs);
     
+    add_pixmap_directory(PACKAGE_DATA_DIR "/pixmaps");
+    debugLog("Pixmap dir: " PACKAGE_DATA_DIR "/pixmaps\n");
+    
     win_main = create_main();
     album_artist = lookup_widget(win_main, "album_artist");
     album_title = lookup_widget(win_main, "album_title");
@@ -353,6 +351,7 @@ void eject_disc(char * cdrom)
 }
 
 static GThread * gbl_cddb_query_thread;
+static int gbl_cddb_query_thread_running;
 static cddb_conn_t * gbl_cddb_query_thread_conn;
 static cddb_disc_t * gbl_cddb_query_thread_disc;
 static int gbl_cddb_query_thread_num_matches;
@@ -360,8 +359,10 @@ static int gbl_cddb_query_thread_num_matches;
 gpointer cddb_query_thread_run(gpointer data)
 {
     gbl_cddb_query_thread_num_matches = cddb_query(gbl_cddb_query_thread_conn, gbl_cddb_query_thread_disc);
+    if(gbl_cddb_query_thread_num_matches == -1)
+        gbl_cddb_query_thread_num_matches = 0;
     
-    gbl_cddb_query_thread = NULL;
+    g_atomic_int_set(&gbl_cddb_query_thread_running, 0);
     
     return NULL;
 }
@@ -376,6 +377,9 @@ GList * lookup_disc(cddb_disc_t * disc)
     if (gbl_cddb_query_thread_conn == NULL)
         fatalError("cddb_new() failed. Out of memory?");
     
+    cddb_set_server_name(gbl_cddb_query_thread_conn, global_prefs->cddb_server_name);
+    cddb_set_server_port(gbl_cddb_query_thread_conn, global_prefs->cddb_port_number);
+    
     if (global_prefs->use_proxy)
     {
         cddb_set_http_proxy_server_name(gbl_cddb_query_thread_conn, global_prefs->server_name);
@@ -384,67 +388,25 @@ GList * lookup_disc(cddb_disc_t * disc)
     }
     
     // query cddb to find similar discs
+    g_atomic_int_set(&gbl_cddb_query_thread_running, 1);
     gbl_cddb_query_thread_disc = disc;
     gbl_cddb_query_thread = g_thread_create(cddb_query_thread_run, NULL, TRUE, NULL);
     
     // show cddb update window
     gdk_threads_enter();
-        //~ GtkWidget* window;
-        //~ GtkWidget* box;
-        //~ GtkWidget* label;
-        
-        //~ window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-        //~ gtk_window_set_transient_for(GTK_WINDOW(window), GTK_WINDOW(win_main));
-        //~ gtk_window_set_modal(GTK_WINDOW(window), TRUE);
-        //~ gtk_window_set_title(GTK_WINDOW(window), "Asunder - CDDB");
-        //~ gtk_window_set_decorated(GTK_WINDOW(window), FALSE);
-        //~ g_signal_connect((gpointer)window, "delete-event",
-                          //~ G_CALLBACK (on_cddb_update_closed), &window);
-        
-        //~ box = gtk_vbox_new (FALSE, 5);
-        //~ gtk_widget_show (box);
-        //~ gtk_container_add (GTK_CONTAINER(window), box);
-        
-        //~ label = gtk_label_new(_("<b>Getting disc info from the internet...</b>"));
-        //~ gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-        //~ gtk_box_pack_start(GTK_BOX (box), label, FALSE, FALSE, 0);
-        //~ gtk_widget_show(label);
-        
-        //~ GtkWidget* button;
-        //~ button = gtk_button_new_from_stock ("gtk-close");
-        //~ gtk_widget_show (button);
-        //~ gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
-        //~ g_signal_connect((gpointer)button, "clicked",
-                          //~ G_CALLBACK (on_cddb_update_close_clicked), &window);
-        
-        //~ gtk_widget_show(window);
-        
-        //~ GtkWidget* dialog;
-        //~ dialog = gtk_message_dialog_new(GTK_WINDOW(win_main),
-                                        //~ GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        //~ GTK_MESSAGE_ERROR,
-                                        //~ GTK_BUTTONS_CLOSE,
-                                        //~ _("<b>Getting disc info from the internet...</b>"));
-        //~ gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-        //~ gtk_dialog_run(GTK_DIALOG(dialog));
-        
         disable_all_main_widgets();
         
         GtkWidget* statusLbl = lookup_widget(win_main, "statusLbl");
         gtk_label_set_text(GTK_LABEL(statusLbl), _("<b>Getting disc info from the internet...</b>"));
         gtk_label_set_use_markup(GTK_LABEL(statusLbl), TRUE);
         
-        while(gbl_cddb_query_thread != NULL)
+        while(g_atomic_int_get(&gbl_cddb_query_thread_running) != 0)
         {
             while (gtk_events_pending())
                 gtk_main_iteration();
             usleep(100000);
         }
         
-        //~ if(window != NULL) /* could have been closed otherwise */
-            //~ gtk_widget_destroy(window);
-        //~ gtk_widget_destroy(dialog);
-        
         gtk_label_set_text(GTK_LABEL(statusLbl), "");
         
         enable_all_main_widgets();
@@ -516,10 +478,9 @@ cddb_disc_t * read_disc(char * cdrom)
         // see if we can read the disc's table of contents (TOC).
         if (ioctl(fd, CDIOREADTOCHEADER, &th) == 0)
         {
-#ifdef DEBUG
-            printf("starting track: %d\n", th.starting_track);
-            printf("ending track: %d\n", th.ending_track);
-#endif
+            debugLog("starting track: %d\n", th.starting_track);
+            debugLog("ending track: %d\n", th.ending_track);
+            
             disc = cddb_disc_new();
             if (disc == NULL)
                 fatalError("cddb_disc_new() failed. Out of memory?");
@@ -564,10 +525,9 @@ cddb_disc_t * read_disc(char * cdrom)
         // see if we can read the disc's table of contents (TOC).
         if (ioctl(fd, CDROMREADTOCHDR, &th) == 0)
         {
-#ifdef DEBUG
-            printf("starting track: %d\n", th.cdth_trk0);
-            printf("ending track: %d\n", th.cdth_trk1);
-#endif
+            debugLog("starting track: %d\n", th.cdth_trk0);
+            debugLog("ending track: %d\n", th.cdth_trk1);
+            
             disc = cddb_disc_new();
             if (disc == NULL)
                 fatalError("cddb_disc_new() failed. Out of memory?");
@@ -653,7 +613,7 @@ void update_tracklist(cddb_disc_t * disc)
 void refresh(char * cdrom, int force)
 {
     cddb_disc_t * disc;
-    GList * curr;
+    //GList * curr;
     
     if(working)
     /* don't do nothing */
@@ -673,22 +633,31 @@ void refresh(char * cdrom, int force)
         update_tracklist(disc);
         
         // clear out the previous list of matches
-        for (curr = g_list_first(disc_matches); curr != NULL; curr = g_list_next(curr))
+        /* this causes a segfault in the following scenario:
+        - disable auto cddb lookup
+        - insert cd that has a record in cddb
+        - click 'cddb lookup'
+        - wait for lookup to finish successfully and eject the disk
+        - reinsert the disk
+        - click 'cddb lookup'
+        - it crashes in the following loop (legrand-sw 14 sep 2008)
+        for (curr = g_list_first(gbl_disc_matches); curr != NULL; curr = g_list_next(curr))
         {
             cddb_disc_destroy((cddb_disc_t *)curr->data);
         }
-        g_list_free(disc_matches);
+        g_list_free(gbl_disc_matches);
+        */
         
         if (!global_prefs->do_cddb_updates && !force)
             return;
         
-        disc_matches = lookup_disc(disc);
+        gbl_disc_matches = lookup_disc(disc);
         cddb_disc_destroy(disc);
         
-        if (disc_matches == NULL)
+        if (gbl_disc_matches == NULL)
             return;
         
-        if (g_list_length(disc_matches) > 1)
+        if (g_list_length(gbl_disc_matches) > 1)
         {
             // fill in and show the album drop-down box
             GtkListStore * store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
@@ -696,7 +665,7 @@ void refresh(char * cdrom, int force)
             GList * curr;
             cddb_disc_t * tempdisc;
             
-            for (curr = g_list_first(disc_matches); curr != NULL; curr = g_list_next(curr))
+            for (curr = g_list_first(gbl_disc_matches); curr != NULL; curr = g_list_next(curr))
             {
                 tempdisc = (cddb_disc_t *)curr->data;
                 gtk_list_store_append(store, &iter);
@@ -713,6 +682,6 @@ void refresh(char * cdrom, int force)
             gtk_widget_show(lookup_widget(win_main, "pick_disc"));
         }
         
-        update_tracklist((cddb_disc_t *)g_list_nth_data(disc_matches, 0));
+        update_tracklist((cddb_disc_t *)g_list_nth_data(gbl_disc_matches, 0));
     }
 }
