@@ -19,8 +19,187 @@ Foundation; version 2 of the licence.
 #include <limits.h>
 #include <ctype.h>
 #include <errno.h>
+#include <gtk/gtk.h>
+#include <stdarg.h>
 
 #include "util.h"
+#include "main.h"
+#include "support.h"
+#include "prefs.h"
+
+void debugLog(const char* format, ...)
+{
+    va_list ap;
+    const char* p = format;
+    
+    FILE* logFile = NULL;
+    
+    if(global_prefs->do_log)
+    {
+        logFile = fopen(LOG_FILE, "a");
+        if(logFile == NULL)
+            return;
+    }
+    
+    va_start(ap, format);
+    
+    time_t currentTime = time(NULL);
+    char* currentTimeStr = ctime(&currentTime);
+    currentTimeStr[strlen(currentTimeStr) - 1] = '\0';
+    
+    while (*p && *(p + 1))
+    {
+        if (*p == '%')
+        {
+            if (*(p + 1) == 'd')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%d", va_arg(ap, int));
+#ifdef DEBUG
+                printf("%d", va_arg(ap, int));
+#endif
+            }
+            else if (*(p + 1) == 'x')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%x", va_arg(ap, unsigned int));
+#ifdef DEBUG
+                printf("%x", va_arg(ap, unsigned int));
+#endif
+            }
+            else if (*(p + 1) == 'X')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%X", va_arg(ap, unsigned int));
+#ifdef DEBUG
+                printf("%X", va_arg(ap, unsigned int));
+#endif
+            }
+            else if (*(p + 1) == 'o')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%o", va_arg(ap, unsigned int));
+#ifdef DEBUG
+                printf("%o", va_arg(ap, unsigned int));
+#endif
+            }
+            else if (*(p + 1) == 'u')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%u", va_arg(ap, unsigned int));
+#ifdef DEBUG
+                printf("%u", va_arg(ap, unsigned int));
+#endif
+            }
+            else if (*(p + 1) == '.' && *(p + 2) && *(p + 2) >= '0' && *(p + 2) <= '9' && 
+                     *(p + 3) && *(p + 3) == 'f')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+#ifdef DEBUG
+                printf("%.2lf", va_arg(ap, double));
+#endif
+                p += 2;
+            }
+            else if(*(p + 1) == 'f')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+#ifdef DEBUG
+                printf("%.2lf", va_arg(ap, double));
+#endif
+            }
+            else if (*(p + 1) == '.' && *(p + 2) && *(p + 2) >= '0' && *(p + 2) <= '9' && 
+                     *(p + 3) && *(p + 3) == 'l' && *(p + 4) && *(p + 4) == 'f')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+#ifdef DEBUG
+                printf("%.2lf", va_arg(ap, double));
+#endif
+                p += 3;
+            }
+            else if(*(p + 1) == 'l' && *(p + 2) && *(p + 2) == 'f')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+#ifdef DEBUG
+                printf("%.2lf", va_arg(ap, double));
+#endif
+            }
+            else if (*(p + 1) == 'c')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%c", (char)va_arg(ap, int));
+#ifdef DEBUG
+                printf("%c", (char)va_arg(ap, int));
+#endif
+            }
+            else if (*(p + 1) == 's')
+            {
+                char* str = va_arg(ap, char*);
+                if (str == NULL)
+                {
+                    if(global_prefs->do_log)
+                        fprintf(logFile, "NULL");
+#ifdef DEBUG
+                    printf("NULL");
+#endif
+                }
+                else
+                {
+                    if(global_prefs->do_log)
+                        fprintf(logFile, "%s", str);
+#ifdef DEBUG
+                    printf("%s", str);
+#endif
+                }
+            }
+            else if (*(p + 1) == '%')
+            {
+                if(global_prefs->do_log)
+                    fprintf(logFile, "%%");
+#ifdef DEBUG
+                printf("%%");
+#endif
+            }
+            else 
+            {
+                //~ fprintf(logFile, "<<%d %d %d %d %d %d %d %d>>\n",
+                //~ *(p + 1) == '.', *(p + 2), *(p + 2) >= 0, *(p + 2) <= 9, 
+                      //~ *(p + 3), *(p + 3) == 'l', *(p + 4), *(p + 4) == 'f');
+                if(global_prefs->do_log)
+                    fprintf(logFile, "unsupported format flag '%c'", *(p + 1));
+#ifdef DEBUG
+                printf("unsupported format flag '%c'", *(p + 1));
+#endif
+                break;
+            }
+            p++;
+        }
+        else /* last character on the line */
+        {
+            if(global_prefs->do_log)
+                fprintf(logFile, "%c", *p);
+#ifdef DEBUG
+            printf("%c", *p);
+#endif
+        }
+        
+        p++;
+    }
+    if (*p)
+    {
+        if(global_prefs->do_log)
+            fprintf(logFile, "%c", *p);
+#ifdef DEBUG
+        printf("%c", *p);
+#endif
+    }
+    
+    if(global_prefs->do_log)
+        fclose(logFile);
+}
 
 void fatalError(const char* message)
 {
@@ -28,6 +207,26 @@ void fatalError(const char* message)
     exit(-1);
 }
 
+int int_to_monkey_int(int i)
+{
+    switch(i)
+    {
+    case 0:
+        return 1000;
+    case 1:
+        return 2000;
+    case 2:
+        return 3000;
+    case 3:
+        return 4000;
+    case 4:
+        return 5000;
+    }
+    
+    fprintf(stderr, "int_to_monkey_int() called with bad parameter\n");
+    return 3000;
+}
+
 int int_to_vbr_int(int i)
 {
     switch(i)
@@ -36,24 +235,25 @@ int int_to_vbr_int(int i)
     case 1:
     case 2:
     case 3:
-    case 4:
         return 9;
-    case 5:
+    case 4:
         return 8;
-    case 6:
+    case 5:
         return 7;
-    case 7:
+    case 6:
         return 6;
-    case 8:
+    case 7:
         return 5;
-    case 9:
+    case 8:
         return 4;
-    case 10:
+    case 9:
         return 3;
-    case 11:
+    case 10:
         return 2;
-    case 12:
+    case 11:
         return 1;
+    case 12:
+        return 0;
     case 13:
     case 14:
         return 0;
@@ -63,6 +263,26 @@ int int_to_vbr_int(int i)
     return 4;
 }
 
+int int_to_musepack_int(int i)
+{
+    switch(i)
+    {
+    case 0:
+        return 3;
+    case 1:
+        return 4;
+    case 2:
+        return 5;
+    case 3:
+        return 6;
+    case 4:
+        return 7;
+    }
+    
+    fprintf(stderr, "int_to_musepack_int() called with bad parameter\n");
+    return 5;
+}
+
 // converts a gtk slider's integer range to a meaningful bitrate
 //
 // NOTE: i grabbed these bitrates from the list in the LAME man page
@@ -93,27 +313,27 @@ int int_to_bitrate(int i, bool vbr)
             return 56;
     case 4:
         if(vbr)
-            return 65;
+            return 85;
         else
             return 64;
     case 5:
         if(vbr)
-            return 85;
+            return 100;
         else
             return 80;
     case 6:
         if(vbr)
-            return 100;
+            return 115;
         else
             return 96;
     case 7:
         if(vbr)
-            return 115;
+            return 130;
         else
             return 112;
     case 8:
         if(vbr)
-            return 130;
+            return 165;
         else
             return 128;
     case 9:
@@ -143,10 +363,54 @@ int int_to_bitrate(int i, bool vbr)
             return 320;
     }
     
-    fprintf(stderr, "int_to_bitrate() called with bad parameter\n");
+    fprintf(stderr, "int_to_bitrate() called with bad parameter (%d)\n", i);
     return 32;
 }
 
+int int_to_wavpack_bitrate(int i)
+{
+    switch (i)
+    {
+    case 0:
+        return 196;
+    case 1:
+        return 256;
+    case 2:
+        return 320;
+    case 3:
+        return 384;
+    case 4:
+        return 448;
+    case 5:
+        return 512;
+    case 6: // some format_wavpack_bitrate() weirdness
+        return 512;
+    }
+    
+    fprintf(stderr, "int_to_wavpack_bitrate() called with bad parameter (%d)\n", i);
+    return 192;
+}
+
+int int_to_musepack_bitrate(int i)
+{
+    switch (i)
+    {
+    case 0:
+        return 90;
+    case 1:
+        return 130;
+    case 2:
+        return 180;
+    case 3:
+        return 210;
+    case 4:
+        return 240;
+    }
+    
+    fprintf(stderr, "int_to_wavpack_bitrate() called with bad parameter (%d)\n", i);
+    return 90;
+}
+
 // construct a filename from various parts
 //
 // path - the path the file is placed in (don't include a trailing '/')
@@ -214,6 +478,46 @@ char * make_filename(const char * path, const char * dir, const char * file, con
     return ret;
 }
 
+void make_playlist(const char* filename, FILE** file)
+{
+    bool makePlaylist;
+    int rc;
+    struct stat statStruct;
+    
+    rc = stat(filename, &statStruct);
+    if(rc == 0)
+    {
+        if(confirmOverwrite(filename))
+            makePlaylist = true;
+        else
+            makePlaylist = false;
+    }
+    else
+        makePlaylist = true;
+    
+    if(makePlaylist)
+    {
+        *file = fopen(filename, "w");
+        
+        if (*file == NULL)
+        {
+            GtkWidget * dialog;
+            dialog = gtk_message_dialog_new(GTK_WINDOW(win_main), 
+                                            GTK_DIALOG_DESTROY_WITH_PARENT, 
+                                            GTK_MESSAGE_ERROR, 
+                                            GTK_BUTTONS_OK, 
+                                            "Unable to create WAV playlist \"%s\": %s", 
+                                            filename, strerror(errno));
+            gtk_dialog_run(GTK_DIALOG(dialog));
+            gtk_widget_destroy(dialog);
+        } else {
+            fprintf(*file, "#EXTM3U\n");
+        }
+    }
+    else
+        *file = NULL;
+}
+
 // substitute various items into a formatted string (similar to printf)
 //
 // format - the format of the filename
