@@ -1,9 +1,15 @@
 #include <stdbool.h>
 
+void debugLog(const char* format, ...);
+
 void fatalError(const char* message);
 
+int int_to_monkey_int(int i);
 int int_to_vbr_int(int i);
 int int_to_bitrate(int i, bool vbr);
+int int_to_wavpack_bitrate(int i);
+int int_to_musepack_bitrate(int i);
+int int_to_musepack_int(int i);
 
 // substitute various items into a formatted string (similar to printf)
 //
@@ -27,6 +33,8 @@ char * parse_format(const char * format, int tracknum, const char * artist, cons
 // NOTE: any of the parameters may be NULL to be omitted
 char * make_filename(const char * path, const char * dir, const char * file, const char * extension);
 
+void make_playlist(const char* pathAndName, FILE** file);
+
 // reads an entire line from a file and returns it
 //
 // NOTE: caller must free the returned string!
